@@ -1,5 +1,5 @@
-/* -*- Mode: C; c-file-style: "gnu"; -*- */
-/* GObject introspection: Repository implementation
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+ * GObject introspection: Repository implementation
  *
  * Copyright (C) 2005 Matthias Clasen
  * Copyright (C) 2008 Colin Walters <walters@verbum.org>
@@ -93,7 +93,9 @@ g_irepository_init (GIRepository *repository)
 			     (GDestroyNotify) NULL,
 			     (GDestroyNotify) g_typelib_free);
   repository->priv->lazy_typelibs
-    = g_hash_table_new (g_str_hash, g_str_equal);
+    = g_hash_table_new_full (g_str_hash, g_str_equal,
+                             (GDestroyNotify) g_free,
+                             (GDestroyNotify) NULL);
   repository->priv->info_by_gtype
     = g_hash_table_new_full (g_direct_hash, g_direct_equal,
                              (GDestroyNotify) NULL,
